@@ -10,7 +10,7 @@ from django.db.models.signals import post_delete
 from django.dispatch import receiver
 
 
-class Risk(NetBoxModel):
+class Aduser(NetBoxModel):
     name = models.CharField(
         max_length=250,
         unique=False
@@ -149,7 +149,7 @@ class RiskAssignment(WebhooksMixin, ChangeLoggedModel):
         return reverse('plugins:users_and_computers:risk', args=[self.risk.pk])
 
 
-@receiver(post_delete, sender=Risk, dispatch_uid='del_risk_assignment')
+@receiver(post_delete, sender=Aduser, dispatch_uid='del_risk_assignment')
 def del_assignments(sender, **kwargs):
     content_type_id = ContentType.objects.get(model='risk').id
     instance_id = kwargs.get('instance').id
