@@ -6,21 +6,22 @@ from django.http import HttpResponseRedirect
 
 
 class RiskView(generic.ObjectView):
-    queryset = models.Risk.objects.all()
+    queryset = models.Aduser.objects.all()
+
 
 class RiskListView(generic.ObjectListView):
-    queryset = models.Risk.objects.all()
+    queryset = models.Aduser.objects.all()
     table = tables.RiskTable
     # actions = ('add', 'export')
 
 
 class RiskEditView(generic.ObjectEditView):
-    queryset = models.Risk.objects.all()
+    queryset = models.Aduser.objects.all()
     form = forms.RiskForm
 
 
 class RiskDeleteView(generic.ObjectDeleteView):
-    queryset = models.Risk.objects.all()
+    queryset = models.Aduser.objects.all()
 
 
 # PTRisk relation
